#include <gtk/gtk.h>

#include "hello-gtk-led.h"
#include "hello-gtk-backlight.h"

static gboolean my_delete_event_handler(GtkWidget *widget,
					GdkEvent  *event,
					gpointer   data)
{
	g_print("delete!\n");

	return FALSE;
}

static void my_destroy_handler(GtkWidget *widget,
			       gpointer   data)
{
	g_print("destroy!\n");

	gtk_main_quit();
}

static void my_clicked_handler(GtkWidget *window,
			       gpointer   data)
{
	g_print("clicked!\n");

	gtk_widget_destroy(window);
}

static void my_toggled_handler(GtkToggleButton *button,
			       gpointer   data)
{
	if (gtk_toggle_button_get_active(button)) {
		gtk_button_set_label(GTK_BUTTON(button), "active!");
		led_set(LED_ON);
	}
	else {
		gtk_button_set_label(GTK_BUTTON(button), "inactive!");
		led_set(LED_OFF);
	}
}

static void my_value_changed_handler(GtkRange *range,
				     gpointer data)
{
	backlight_set((int)gtk_range_get_value(range));
}

int main(int argc, char *argv[])
{
	GtkWidget *window;
	GtkWidget *bbox;
	GtkWidget *button;
	GtkWidget *toggle;
	GtkWidget *vbox;
	GtkWidget *scale;

	gtk_init(&argc, &argv);
	led_setup();
	backlight_setup();

	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	bbox   = gtk_hbutton_box_new();
	button = gtk_button_new();
	toggle = gtk_toggle_button_new_with_label("inactive!");
	vbox   = gtk_vbox_new(TRUE, 0);
	scale  = gtk_hscale_new_with_range(10, 200, 10);

	gtk_button_set_label(GTK_BUTTON(button), "Stop!");
	gtk_range_set_value(GTK_RANGE(scale), backlight_get());

	g_signal_connect(G_OBJECT(scale), "value-changed",
			 G_CALLBACK(my_value_changed_handler),
			 NULL);
	g_signal_connect(G_OBJECT(toggle), "toggled",
			 G_CALLBACK(my_toggled_handler),
			 NULL);
	g_signal_connect_swapped(G_OBJECT(button), "clicked",
				 G_CALLBACK(my_clicked_handler),
				 (gpointer)window);
	g_signal_connect(G_OBJECT(window), "delete-event",
			 G_CALLBACK(my_delete_event_handler),
			 NULL);
	g_signal_connect(G_OBJECT(window), "destroy",
			 G_CALLBACK(my_destroy_handler),
			 NULL);

	gtk_window_fullscreen(GTK_WINDOW(window));
	gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox),
				  GTK_BUTTONBOX_SPREAD);

	gtk_container_add(GTK_CONTAINER(bbox), button);
	gtk_container_add(GTK_CONTAINER(bbox), toggle);

	gtk_box_pack_start_defaults(GTK_BOX(vbox), scale);
	gtk_box_pack_start_defaults(GTK_BOX(vbox), bbox);

	gtk_container_set_border_width(GTK_CONTAINER(vbox), 40);
	gtk_container_add(GTK_CONTAINER(window), vbox);

	gtk_widget_show_all(window);

	gtk_main();
	led_teardown();
	backlight_teardown();

	return 0;
}
